import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sk_base_mobile/app_theme.dart';
import 'package:sk_base_mobile/db_helper/dbHelper.dart';
import 'package:sk_base_mobile/screens/new_inventory_inout/new_inventory_inout.dart';
import 'package:sk_base_mobile/util/date.util.dart';
import 'package:sk_base_mobile/util/logger_util.dart';
import 'package:sk_base_mobile/util/modal.util.dart';
import 'package:sk_base_mobile/util/screen_adaper_util.dart';

import 'components/responsive.dart';

class InventoryInoutController extends GetxController {
  RxMap userData = {}.obs;
  RxInt currentIndex = 0.obs;
  final PageController pageController = PageController();
  final DateTime dateTime = DateTime.now();
  final DbHelper db = DbHelper();
  List<RxList> list = [
    [].obs,
    [].obs,
    [].obs,
    [].obs,
    [].obs,
    [].obs,
    [].obs,
  ].obs;
  RxInt barIndex = 0.obs;
  RxList model = [].obs;
  final ScrollController scrollController = ScrollController();

  Future<void> showInOrOutPickerDialog() async {
    showDialog(
      context: Get.overlayContext!,
      builder: (_) => Align(
          alignment: Alignment.center,
          widthFactor: 1,
          heightFactor: 1,
          child: SizedBox(
              width: ScreenAdaper.width(1000),
              height: ScreenAdaper.height(500),
              child: TweenAnimationBuilder(
                curve: Curves.easeInOut,
                tween: Tween<double>(begin: 0, end: 1),
                duration: const Duration(milliseconds: 200),
                builder: (context, value, child) {
                  return Stack(
                    alignment: Alignment.center,
                    children: [
                      AnimatedPositioned(
                        duration: const Duration(milliseconds: 100),
                        left: value * 80,
                        child: GestureDetector(
                            onTap: () {
                              Get.back();
                              showInventoryInoutCreateDialog();
                            },
                            child: Container(
                              height: ScreenAdaper.height(350),
                              width: ScreenAdaper.height(350),
                              decoration: const BoxDecoration(
                                borderRadius:
                                    BorderRadius.all(Radius.circular(30)),
                                gradient: LinearGradient(colors: [
                                  AppTheme.primaryColorLight,
                                  AppTheme.primaryColor
                                ]),
                              ),
                              alignment: Alignment.center,
                              child: Column(
                                  mainAxisAlignment: MainAxisAlignment.center,
                                  children: [
                                    Icon(
                                      Icons.add_circle_outline,
                                      color: AppTheme.nearlyWhite,
                                      size: ScreenAdaper.sp(80),
                                    ),
                                    SizedBox(
                                      height: ScreenAdaper.height(10),
                                    ),
                                    Text(
                                      '入库',
                                      style: TextStyle(
                                          decoration: TextDecoration.none,
                                          color: AppTheme.nearlyWhite,
                                          fontSize: ScreenAdaper.sp(60),
                                          letterSpacing: ScreenAdaper.width(5),
                                          fontWeight: FontWeight.w700),
                                    )
                                  ]),
                            )),
                      ),
                      AnimatedPositioned(
                          duration: const Duration(milliseconds: 100),
                          right: 80 * value,
                          child: GestureDetector(
                            onTap: () {
                              Get.back();
                              showInventoryInoutCreateDialog();
                            },
                            child: Container(
                                height: ScreenAdaper.height(350),
                                width: ScreenAdaper.height(350),
                                decoration: const BoxDecoration(
                                  // shape: BoxShape.circle,
                                  borderRadius:
                                      BorderRadius.all(Radius.circular(30)),
                                  gradient: LinearGradient(colors: [
                                    AppTheme.primaryColorLight,
                                    AppTheme.primaryColor
                                  ]),
                                ),
                                alignment: Alignment.center,
                                child: Column(
                                    mainAxisAlignment: MainAxisAlignment.center,
                                    children: [
                                      Icon(
                                        // 减号、
                                        Icons.remove_circle_outline,
                                        color: AppTheme.nearlyWhite,
                                        size: ScreenAdaper.sp(80),
                                      ),
                                      SizedBox(
                                        height: ScreenAdaper.height(10),
                                      ),
                                      Text(
                                        '出库',
                                        style: TextStyle(
                                            decoration: TextDecoration.none,
                                            color: AppTheme.nearlyWhite,
                                            fontSize: ScreenAdaper.sp(60),
                                            letterSpacing:
                                                ScreenAdaper.width(5),
                                            fontWeight: FontWeight.w700),
                                      )
                                    ])),
                          )),
                    ],
                  );
                },
              ))),
    );
  }

  /// 打开新建库存出入库对话框
  Future<void> showInventoryInoutCreateDialog() async {
    final isTablet = Responsive.isTablet(Get.context!);
    print(isTablet);
    isTablet
        ? showGeneralDialog(
            context: Get.overlayContext!,
            barrierLabel: "CreateInventoryInout",
            barrierDismissible: true,
            transitionDuration: const Duration(milliseconds: 400),
            pageBuilder: (_, __, ___) {
              return Container(
                margin: EdgeInsets.symmetric(
                    horizontal: ScreenAdaper.width(100),
                    vertical: ScreenAdaper.height(100)),
                child: ClipRRect(
                    borderRadius: BorderRadius.circular(30),
                    child: Material(child: NewInventoryInout())),
              );
            },
            transitionBuilder: (_, anim, __, child) {
              Tween<Offset> tween;
              tween = Tween(begin: const Offset(0, -1), end: Offset.zero);
              return SlideTransition(
                position: tween.animate(
                  CurvedAnimation(parent: anim, curve: Curves.easeInOut),
                ),
                child: child,
              );
            },
          )
        : showModalBottomSheet(
            elevation: 0,
            isScrollControlled: true,
            backgroundColor: Colors.white,
            context: Get.overlayContext!,
            builder: (context) {
              return NewInventoryInout();
            },
          );
  }

  getTasks() async {
    db.getData().then((value) {
      model.value = value;
      getSepretLists();
    });
  }

  setIndex(int value) {
    pageController.animateToPage(value,
        duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    currentIndex.value = value;
  }

  getDateAccordingTabs(int value) {
    return '${DateUtil.addPrefix(dateTime.add(Duration(days: value)).day.toString())}/${DateUtil.addPrefix(dateTime.add(Duration(days: value)).month.toString())}/${DateUtil.addPrefix(dateTime.add(Duration(days: value)).year.toString())}';
  }

  getSepretLists() {
    List<RxList<dynamic>> tempList = [];
    for (int i = 0; i < 7; i++) {
      RxList tempList1 = [].obs;
      tempList1.clear();
      for (int j = 0; j < model.length; j++) {
        if (model[j].date == getDateAccordingTabs(i)) {
          tempList1.add(model[j]);
        }
      }
      tempList.add(tempList1);
    }
    list = tempList;
  }

  onMoveNextPage() {
    if (currentIndex.value < 7) {
      setIndex(currentIndex.value + 1);
    }
  }

  onMoveBack() {
    if (currentIndex.value > 0) {
      setIndex(currentIndex.value - 1);
    }
  }

  onTaskComplete(
      int value, int index, int ind, String key, BuildContext context) {
    switch (value) {
      case 3:
        {
          ModalUtil.showWarningDialog('Complete Task',
              'This task will be marked as completed', 'Confirm', () {
            list[ind][index].status = 'complete';
            list[ind].add('');
            list[ind].remove('');
            db.update(key, 'status', 'complete');
          });
        }
      case 2:
        {
          ModalUtil.showWarningDialog(
              'Delete Task', 'Are you want to sure to remove', 'Confirm', () {
            list[ind].remove(list[ind][index]);
            db.delete(
              key,
              'Tasks',
            );
          });
        }
    }
  }
}
