import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_typeahead/flutter_typeahead.dart';
import 'package:get/get.dart';
import 'package:sk_base_mobile/app_theme.dart';
import 'package:sk_base_mobile/constants/constants.dart';
import 'package:sk_base_mobile/models/product.model.dart';
import 'package:sk_base_mobile/screens/new_inventory_inout/components/category_input.dart';
import 'package:sk_base_mobile/screens/new_inventory_inout/components/date_time.dart';
import 'package:sk_base_mobile/screens/new_inventory_inout/components/description_input.dart';
import 'package:sk_base_mobile/screens/new_inventory_inout/components/lable_input.dart';
import 'package:sk_base_mobile/widgets/gradient_button.dart';
import 'package:sk_base_mobile/screens/new_inventory_inout/new_inventory_inout_controller.dart';
import 'package:sk_base_mobile/screens/inventory_inout/components/responsive.dart';
import 'package:sk_base_mobile/util/screen_adaper_util.dart';

class NewInventoryInout extends StatelessWidget {
  NewInventoryInout({super.key});

  final controller = Get.put(NewInventoryInoutController());

  @override
  Widget build(BuildContext context) {
    return Container(
      height: ScreenAdaper.height(800),
      width: Get.width,
      decoration: const BoxDecoration(
        color: Colors.white,
      ),
      child: ClipRRect(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(
                ScreenAdaper.sp(30),
              ),
              topRight: Radius.circular(ScreenAdaper.sp(30))),
          child: GestureDetector(
              behavior: HitTestBehavior.translucent,
              onTap: () {
                // 点击空白处时收起键盘
                FocusScope.of(Get.context!).unfocus();
              },
              child: Stack(
                children: [
                  Positioned.fill(
                      child: Column(
                    children: [
                      buildTitle(),
                      Expanded(
                        child: SingleChildScrollView(
                          child: buildForm(),
                        ),
                      ),
                      Obx(() => GradientButton(
                            onPressed: () => {controller.insertTask(context)},
                            isLoading: controller.loading.value,
                          ))
                    ],
                  ))
                ],
              ))),
    );
  }

  Widget buildTitle() {
    return Container(
      decoration: const BoxDecoration(
          border: Border(bottom: BorderSide(color: AppTheme.dividerColor))),
      padding: EdgeInsets.symmetric(
          vertical: ScreenAdaper.height(5), horizontal: ScreenAdaper.width(20)),
      child: Row(
        children: [
          Text(
            TextEnum.inventoryInOutDialogTitle,
            style: TextStyle(
              fontSize: ScreenAdaper.sp(25),
              fontWeight: FontWeight.w700,
            ),
          ),
          const Spacer(),
          IconButton(
              onPressed: () {
                Get.back();
              },
              icon: Icon(
                Icons.close,
                size: ScreenAdaper.sp(30),
              ))
        ],
      ),
    );
  }

  Widget buildForm() {
    final children = [
      Row(children: [
        Expanded(
          flex: 1,
          child: buildInoutPicker(),
        ),
        SizedBox(
          width: ScreenAdaper.width(10),
        ),
        Expanded(
          flex: 3,
          child: buildProductPicker(),
        )
      ]),
    ];

    final child = Column(
      mainAxisAlignment: MainAxisAlignment.center,
      mainAxisSize: MainAxisSize.max,
      children: children,
    );

    return Form(
        key: controller.formKey,
        child: Container(
          padding: EdgeInsets.symmetric(
              vertical: ScreenAdaper.height(20),
              horizontal: ScreenAdaper.width(20)),
          alignment: Alignment.center,
          child: child,
        ));
  }

  Widget buildInoutPicker() {
    // 选择下拉框表单项 两个选项 picker
    return DropdownButtonFormField<String>(
      style:
          TextStyle(fontSize: ScreenAdaper.sp(22), color: AppTheme.nearlyBlack),
      // value: _dropdownValue,
      decoration: InputDecoration(
        border: OutlineInputBorder(
            borderRadius: BorderRadius.circular(ScreenAdaper.sp(15))),
        labelText: "出/入库",
      ),
      onChanged: (String? newValue) {
        // setState(() {
        //   _dropdownValue = newValue;
        // });
      },
      items: <String>[
        '入库',
        '出库',
      ].map<DropdownMenuItem<String>>((String value) {
        return DropdownMenuItem<String>(
          value: value,
          child: Text(value),
        );
      }).toList(),
    );
  }

  Widget buildProductPicker() {
    return TypeAheadField<ProductModel>(suggestionsCallback: (search) {
      return [ProductModel(name: 'aaa'), ProductModel(name: 'bbb')];
    }, builder: (context, controller, focusNode) {
      return TextField(
          controller: controller,
          focusNode: focusNode,
          decoration: InputDecoration(
            border: OutlineInputBorder(
                borderRadius: BorderRadius.circular(ScreenAdaper.sp(15))),
            labelText: "选择产品",
          ));
    }, itemBuilder: (context, product) {
      return ListTile(
        title: Text(product.name ?? ''),
        subtitle: Text(product.name ?? ''),
      );
    }, onSelected: (city) {
      // Navigator.of(context).push<void>(
      //   MaterialPageRoute(
      //     builder: (context) => CityPage(city: city),
      //   ),
      // );
    });
  }
}
